@@ -1,9 +1,8 @@
 # Converted from Route53_CNAME.template located at:
 # http://aws.amazon.com/cloudformation/aws-cloudformation-templates/
 
-from troposphere import FindInMap, GetAtt, Join, Output
+from troposphere import Join, Output
 from troposphere import Parameter, Ref, Template
-from troposphere.ec2 import Instance
 from troposphere.route53 import RecordSetType
 
 
@@ -17,12 +16,14 @@ t.add_description(
     "You will be billed for the AWS resources used if you create "
     "a stack from this template.")
 
-hostedzone = t.add_parameter(Parameter("HostedZone",
+hostedzone = t.add_parameter(Parameter(
+    "HostedZone",
     Description="The DNS name of an existing Amazon Route 53 hosted zone",
     Type="String",
 ))
 
-myDNSRecord = t.add_resource(RecordSetType("myDNSRecord",
+myDNSRecord = t.add_resource(RecordSetType(
+    "myDNSRecord",
     HostedZoneName=Join("", [Ref(hostedzone), "."]),
     Comment="CNAME redirect to aws.amazon.com.",
     Name=Join("", [Ref("AWS::StackName"), ".", Ref("AWS::Region"), ".",
@@ -33,7 +34,6 @@ myDNSRecord = t.add_resource(RecordSetType("myDNSRecord",
 ))
 
 
-t.add_output(Output("DomainName",
-    Value=Ref(myDNSRecord)))
+t.add_output(Output("DomainName", Value=Ref(myDNSRecord)))
 
-print t.to_json()
+print(t.to_json())
