@@ -10,7 +10,7 @@ import types
 
 from . import validators
 
-__version__ = "0.3.4"
+__version__ = "0.4.0"
 
 # constants for DeletionPolicy
 Delete = 'Delete'
@@ -21,8 +21,9 @@ valid_names = re.compile(r'^[a-zA-Z0-9]+$')
 
 
 class BaseAWSObject(object):
-    def __init__(self, name, **kwargs):
+    def __init__(self, name, template=None, **kwargs):
         self.name = name
+        self.template = template
         # Cache the keys for validity checks
         self.propnames = self.props.keys()
         self.attributes = ['DependsOn', 'DeletionPolicy',
@@ -53,6 +54,10 @@ class BaseAWSObject(object):
             else:
                 self.__setattr__(k, v)
 
+        # Bound it to template if we know it
+        if self.template is not None:
+            self.template.add_resource(self)
+
     def __getattr__(self, name):
         try:
             return self.properties.__getitem__(name)
@@ -60,7 +65,8 @@ class BaseAWSObject(object):
             raise AttributeError(name)
 
     def __setattr__(self, name, value):
-        if '_BaseAWSObject__initialized' not in self.__dict__:
+        if name in self.__dict__.keys() \
+                or '_BaseAWSObject__initialized' not in self.__dict__:
             return dict.__setattr__(self, name, value)
         elif name in self.propnames:
             # Check the type of the object and compare against what we were
@@ -144,6 +150,7 @@ class AWSProperty(BaseAWSObject):
     http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/
     aws-product-property-reference.html
     """
+    dictname = None
 
     def __init__(self, name=None, **kwargs):
         super(AWSProperty, self).__init__(name, **kwargs)
@@ -214,6 +221,14 @@ class GetAZs(AWSHelperFn):
         return self.data
 
 
+class If(AWSHelperFn):
+    def __init__(self, cond, true, false):
+        self.data = {'Fn::If': [self.getdata(cond), true, false]}
+
+    def JSONrepr(self):
+        return self.data
+
+
 class Join(AWSHelperFn):
     def __init__(self, delimiter, values):
         self.data = {'Fn::Join': [delimiter, values]}
@@ -256,7 +271,7 @@ class awsencode(json.JSONEncoder):
 class Tags(AWSHelperFn):
     def __init__(self, **kwargs):
         self.tags = []
-        for k, v in kwargs.iteritems():
+        for k, v in sorted(kwargs.iteritems()):
             self.tags.append({
                 'Key': k,
                 'Value': v,
@@ -278,6 +293,7 @@ class Template(object):
 
     def __init__(self):
         self.description = None
+        self.conditions = {}
         self.mappings = {}
         self.outputs = {}
         self.parameters = {}
@@ -287,6 +303,9 @@ class Template(object):
     def add_description(self, description):
         self.description = description
 
+    def add_condition(self, name, condition):
+        self.conditions[name] = condition
+
     def handle_duplicate_key(self, key):
         raise ValueError('duplicate key "%s" detected' % key)
 
@@ -324,6 +343,8 @@ class Template(object):
         t = {}
         if self.description:
             t['Description'] = self.description
+        if self.conditions:
+            t['Conditions'] = self.conditions
         if self.mappings:
             t['Mappings'] = self.mappings
         if self.outputs:
